{%extends 'therm/base.html'%}

{% block head_include %}
    <link rel="stylesheet" type="text/css" href="/static/css/jquery.jqplot.min.css" />
{% endblock %}

{% block middle_col %}
    <div id="plot_div_day"></div>
    <div id="plot_div_week"></div>
    <div id="plot_div_month"></div>
    <div id="plot_div_year"></div>
{% endblock %}
{% block include_script %}
    <!--[if lt IE 9]><script language="javascript" type="text/javascript" src="/statc/js/excanvas.js"></script><![endif]-->
    <script language="javascript" type="text/javascript" src="/static/js/jquery.jqplot.min.js"></script>
    <script type="text/javascript" src="/static/js/jqplot.dateAxisRenderer.min.js"></script>
{% endblock %}


{%block script%}
    {% include 'therm/js/stats.js' %}
    $("#left_col").removeClass()
    $("#right_col_father").remove()
    $("#middle_col").removeClass()
    $("#left_col").addClass("col-xs-0 col-sm-0 col-md-2 col-lg-2")
    $("#middle_col").addClass("col-xs-12 col-sm-12 col-md-8 col-lg-8")
{%endblock%}

{%block document_ready%}
    load_stats('plot_div_day', 'day')
    load_stats('plot_div_week', 'week')
{%endblock%}